## A Guide for creating Design Tokens
Design tokens are essential particles of a design system, specifically, they are variables that store visual design attributes. They can contain colors (hex, RGBA or other values), sizing units (pixels, rems, etc.) and many more. They're essential for creating and maintaining a consistent visual system.

**Tokens shouldn't be added without prior agreement from the Design and Front-end Team** as they define the visual language of the entire system.

Tokens are stored in `yml` files within the [token folder](https://github.com/envato/foundation-design-system/tree/master/tokens).

### Main token import file
The `app.yml` file imports all of the existing token modules like so:

```yml
  # global is required
  global:
    # category has to be defined at the top of each file
    category: "app"
  # use `imports` to import other files
  imports:
    [
      "./colors.yml",
      "./fonts.yml"
    ]
```

### Individual token file
Each individual token file should have the following format:

```yml
---
  global:
    # category of a token
    category: "spacing"
  # props is required to write `key` and `value` pairs
  props:
    spacing--xs:
      # type is not used in the generated result but is required by the plugin
      # helps to categorize
      value: "4px"
      type: "spacing"
    spacing--s:
      value: "8px"
      type: "spacing"
    spacing--m:
      value: "16px"
      type: "spacing"
    spacing--l:
      value: "24px"
      type: "spacing"
    spacing--xl:
      value: "32px"
      type: "spacing"
```

| Name | Description | Required |
| --- | --- | --- |
| global | meta information can be put here, will have other sub attribute | True |
| category | category attribute, can be `color`, `font` or whatever, required but not used in the output | True |
| imports | import other files | False |
| props | define your key value pair | True |
| type | type of the attribute, not used in the output but required | True |
